mailr10609 - /branches/bieri_gui/gui_bieri/components/spectrum.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on February 01, 2010 - 22:01:
Author: bugman
Date: Mon Feb  1 22:01:24 2010
New Revision: 10609

URL: http://svn.gna.org/viewcvs/relax?rev=10609&view=rev
Log:
Bug fix for the peak list loading GUI element.

The relaxation times were being lost after every click of 'Add'.


Modified:
    branches/bieri_gui/gui_bieri/components/spectrum.py

Modified: branches/bieri_gui/gui_bieri/components/spectrum.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/bieri_gui/gui_bieri/components/spectrum.py?rev=10609&r1=10608&r2=10609&view=diff
==============================================================================
--- branches/bieri_gui/gui_bieri/components/spectrum.py (original)
+++ branches/bieri_gui/gui_bieri/components/spectrum.py Mon Feb  1 22:01:24 
2010
@@ -244,7 +244,8 @@
         for i in range(len(files)):
             self.data.file_list[count+i] = str(files[i])
 
-        # Refresh the GUI element.
+        # Sync any set times and refresh the GUI element.
+        self.sync_ds(upload=True)
         self.refresh_peak_list_display()
 
         # Terminate the event.




Related Messages


Powered by MHonArc, Updated Mon Feb 01 22:40:02 2010